@@ -25,10 +25,8 @@ from define import *
 from main_paras import setMainTopLeft, getMainTopLeft, mainChannelStart, setDetectionMode, getDetectionMode, setTestMode, getTestMode, queueForGui
 from wrong_password import _WrongPassword
 from vkeyboard import handleVisibleChanged
-try:
-    from on_off.mainboard_pio import fanTurnOn
-except Exception as e:
-    print(e)
+if sys.platform == 'linux':
+    from  on_off.mainboard_pio import fanTurnOn
 currentPath=pathlib.Path(__file__).parent.absolute()
 
 
@@ -70,17 +68,19 @@ class MainWindow(QtWidgets.QMainWindow):
         
         
     def tempMonitor(self):
-        try:
-            result=subprocess.check_output(['vcgencmd','measure_temp']).decode("utf-8")
-            tmp=int(float(result.split('=')[1].split('\'')[0]))
-            #print(tmp)
-            if tmp > TEMP_ON_VALUE:
-                fanTurnOn(True)
-            elif tmp < TEMP_OFF_VALUE:
+        if sys.platform == 'linux':
+            try:
+                result=subprocess.check_output(['vcgencmd','measure_temp']).decode("utf-8")
+                tmp=int(float(result.split('=')[1].split('\'')[0]))
+                #print(tmp)
                 fanTurnOn(False)
+                if tmp > TEMP_ON_VALUE:
+                    fanTurnOn(True)
+                elif tmp < TEMP_OFF_VALUE:
+                    fanTurnOn(False)
                 
-        except Exception as error:
-            print(error)
+            except Exception as error:
+                print(error)
         
         
     def config(self):
@@ -181,14 +181,18 @@ class MainWindow(QtWidgets.QMainWindow):
             y = self.geometry().y()
             print('main x, y', x, y)
             setMainTopLeft(x, y)
-
+            
             main_x, main_y =getMainTopLeft()
             self.help.setup(_HelpDialog, main_x, main_y)
-            self.wifi.setup(_WifiList, main_x+225, main_y-7)
-            self.volume.setup(_Volume, main_x+275, main_y-7)
-            self.setting.setup(_SettingDialog, main_x+325, main_y-7)
-            self.profile_icon.setup(_ProfileDialog, main_x+357, main_y-7)
+            self.wifi.setup(_WifiList, main_x+205, main_y-7)
+            self.volume.setup(_Volume, main_x+245, main_y-7)
+            self.setting.setup(_SettingDialog, main_x+303, main_y-7)
+            self.profile_icon.setup(_ProfileDialog, main_x+335, main_y-7)
 
+##            self.wifi.setup(_WifiList, main_x+225, main_y-7)
+##            self.volume.setup(_Volume, main_x+275, main_y-7)
+##            self.setting.setup(_SettingDialog, main_x+325, main_y-7)
+##            self.profile_icon.setup(_ProfileDialog, main_x+357, main_y-7)
             
         except Exception as e:
             print(e)
@@ -214,7 +218,7 @@ class MainWindow(QtWidgets.QMainWindow):
             if slotNo == SIGN_IN_FIRST_INDEX:
                 global popUp
                 popUp = _WrongPassword()
-                popUp.setMessage(self.tr("Sign In first."),self.tr('Ok'))
+                popUp.setMessage(self.tr("Sign in and enter basic test information."),self.tr('Ok'))
                 x,y = getMainTopLeft()
                 popUp.move(x,y)
                 popUp.show()
@@ -235,7 +239,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 self.slots[item[0]].setStatus(SLOT_STATUS_POSITIVE, qrCode)
             elif errCode == Negative_test_result:
                 self.slots[item[0]].setStatus(SLOT_STATUS_NEGATIVE, qrCode)
-            elif errCode == Invalid_image_identifier:
+            elif errCode == Control_area_not_found:
                 self.slots[item[0]].setStatus(SLOT_STATUS_INVALID, qrCode)
             elif errCode == DEVICE_STATE_CASSETTE_EMPTY:
                 self.slots[item[0]].setStatus(SLOT_STATUS_EMPTY, qrCode)
@@ -245,6 +249,10 @@ class MainWindow(QtWidgets.QMainWindow):
             print(e)
         
     def closeEvent(self,event):
+        self.tempPolling.stop()
+        if sys.platform == 'linux':
+            fanTurnOn(False)
+        
         print("Main window is closing")
 
 if __name__ == "__main__":
