@@ -62,11 +62,11 @@ class _HelpDialog(QtWidgets.QDialog):
         sub_window.exec()
         
     def open_whatis(self):
-        self.open_sub_window('Look Spot II '+version, '/home/pi/app/spotii/launcher/contact.html')
+        self.open_sub_window('Look Spot II '+version, '/home/pi/app/spotii/launcher/comming.html')
     def open_more(self):
-        self.open_sub_window(self.tr('More Information'), '/home/pi/app/spotii/launcher/contact.html')
+        self.open_sub_window(self.tr('More Information'), '/home/pi/app/spotii/launcher/comming.html')
     def open_faq(self):
-        self.open_sub_window(self.tr('FAQ'), '/home/pi/app/spotii/launcher/contact.html')
+        self.open_sub_window(self.tr('FAQ'), '/home/pi/app/spotii/launcher/comming.html')
     def open_legal(self):
         self.open_sub_window(self.tr('Legal Notice and Privacy Policy'), '/home/pi/app/spotii/launcher/legal.html')
     def open_contact(self):
